@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: bacon-video-widget-xine.c,v 1.199 2005/07/12 19:39:36 hadess Exp $
+ * $Id: bacon-video-widget-xine.c,v 1.204 2005/08/08 17:57:37 hadess Exp $
  *
  * the xine engine in a widget - implementation
  */
@@ -414,7 +414,6 @@ bacon_video_widget_init (BaconVideoWidget *bvw)
 	bvw->priv = g_new0 (BaconVideoWidgetPrivate, 1);
 	bvw->priv->xine = xine_new ();
 	bvw->priv->cursor_shown = TRUE;
-	bvw->priv->vis_name = g_strdup ("goom");
 	bvw->priv->volume = -1;
 
 	bvw->priv->init_width = 0;
@@ -1141,9 +1140,11 @@ bacon_video_widget_realize (GtkWidget *widget)
 			&& bvw->priv->ao_driver != NULL
 			&& bvw->priv->ao_driver_none == FALSE)
 	{
-		bvw->priv->vis = xine_post_init (bvw->priv->xine,
-				bvw->priv->vis_name, 0,
-				&bvw->priv->ao_driver, &bvw->priv->vo_driver);
+		if (bvw->priv->vis_name == NULL)
+			bvw->priv->vis_name = g_strdup ("goom");
+	} else {
+		g_free (bvw->priv->vis_name);
+		bvw->priv->vis_name = NULL;
 	}
 
 	bvw->priv->have_xvidmode = bacon_resize_init ();
@@ -1270,7 +1271,7 @@ xine_event_message (BaconVideoWidget *bvw, xine_ui_message_data_t *data)
 		message = g_strdup (_("The specified movie could not be found."));
 		break;
 	case XINE_MSG_READ_ERROR:
-		if (bvw->priv->mrl && g_str_has_prefix (bvw->priv->mrl, "dvd:") != FALSE)
+		if (g_str_has_prefix (bvw->priv->mrl, "dvd:") != FALSE)
                 {
                         num = BVW_ERROR_DVD_ENCRYPTED;
                         message = g_strdup (_("The source seems encrypted, and can't be read. Are you trying to play an encrypted DVD without libdvdcss?"));
@@ -1285,7 +1286,7 @@ xine_event_message (BaconVideoWidget *bvw, xine_ui_message_data_t *data)
 			return;
 		/* Only if the file could really not be loaded */
 		num = BVW_ERROR_PLUGIN_LOAD;
-		message = g_strdup_printf (_("A problem occured while loading a library or a decoder (%s)."), params);
+		message = g_strdup_printf (_("A problem occurred while loading a library or a decoder (%s)."), params);
 		break;
 	case XINE_MSG_ENCRYPTED_SOURCE:
 		if (g_str_has_prefix (bvw->priv->mrl, "dvd:") != FALSE)
@@ -1421,7 +1422,7 @@ xine_event (void *user_data, const xine_event_t *event)
 }
 
 static void
-xine_error (BaconVideoWidget *bvw, GError **error)
+xine_try_error (BaconVideoWidget *bvw, gboolean probe_error, GError **error)
 {
 	signal_data *data, *save_data;
 	int err;
@@ -1433,12 +1434,6 @@ xine_error (BaconVideoWidget *bvw, GError **error)
 	 * xine_open() */
 	while ((data = g_async_queue_try_pop (bvw->priv->queue)) != NULL)
 	{
-		g_assert (data->signal == MESSAGE_ASYNC
-				|| data->signal == ERROR_ASYNC
-				|| data->signal == BUFFERING_ASYNC
-				|| data->signal == REDIRECT_ASYNC
-				|| data->signal == EOS_ASYNC);
-
 		if (data->signal == ERROR_ASYNC)
 		{
 			if (save_data != NULL)
@@ -1463,6 +1458,9 @@ xine_error (BaconVideoWidget *bvw, GError **error)
 		return;
 	}
 
+	if (probe_error != FALSE)
+		return;
+
 	err = xine_get_error (bvw->priv->stream);
 	if (err == XINE_ERROR_NONE)
 		return;
@@ -1493,6 +1491,12 @@ xine_error (BaconVideoWidget *bvw, GError **error)
 	}
 }
 
+static void
+xine_error (BaconVideoWidget *bvw, GError **error)
+{
+	xine_try_error (bvw, FALSE, error);
+}
+
 static void
 bacon_video_widget_unrealize (GtkWidget *widget)
 {
@@ -1555,6 +1559,9 @@ bacon_video_widget_unrealize (GtkWidget *widget)
 		xine_close_audio_driver (bvw->priv->xine,
 				bvw->priv->ao_driver);
 
+	if (bvw->priv->vis != NULL)
+		xine_post_dispose (bvw->priv->xine, bvw->priv->vis);
+
 	/* stop event thread */
 	xine_exit (bvw->priv->xine);
 	bvw->priv->xine = NULL;
@@ -1651,7 +1658,6 @@ bacon_video_widget_new (int width, int height,
 		g_async_queue_unref (bvw->priv->queue);
 		g_free (bvw->priv->vis_name);
 		g_object_unref (G_OBJECT (bvw->priv->gc));
-		g_free (bvw->priv->vis_name);
 		g_free (bvw->priv);
 		g_free (bvw);
 
@@ -1845,31 +1851,54 @@ static void
 show_vfx_update (BaconVideoWidget *bvw, gboolean show_visuals)
 {
 	xine_post_out_t *audio_source;
-	gboolean has_video;
+	gboolean has_video, enable;
+
+	if (bvw->priv->vis_name == NULL)
+		return;
 
 	has_video = xine_get_stream_info(bvw->priv->stream,
 			XINE_STREAM_INFO_HAS_VIDEO);
+	enable = FALSE;
 
+	/* Already has video, and we were showing visual effects */
 	if (has_video != FALSE && show_visuals != FALSE
 			&& bvw->priv->using_vfx != FALSE)
 	{
+		enable = FALSE;
+	/* Doesn't have video, should show visual effects, and wasn't doing
+	 * so before */
+	} else if (has_video == FALSE && show_visuals != FALSE
+			&& bvw->priv->using_vfx == FALSE)
+	{
+		if (bvw->priv->vis == NULL) {
+			bvw->priv->vis = xine_post_init (bvw->priv->xine,
+					bvw->priv->vis_name, 0,
+					&bvw->priv->ao_driver,
+					&bvw->priv->vo_driver);
+		}
+		if (bvw->priv->vis != NULL) {
+			enable = TRUE;
+		}
+	/* Doesn't have video, but visual effects are disabled */
+	} else if (has_video == FALSE && show_visuals == FALSE) {
+		enable = FALSE;
+	}
+
+	if (enable == FALSE) {
 		audio_source = xine_get_audio_source (bvw->priv->stream);
 		if (xine_post_wire_audio_port (audio_source,
 					bvw->priv->ao_driver))
 			bvw->priv->using_vfx = FALSE;
-	} else if (has_video == FALSE && show_visuals != FALSE
-			&& bvw->priv->using_vfx == FALSE
-			&& bvw->priv->vis != NULL)
-	{
+		if (bvw->priv->vis != NULL) {
+			xine_post_dispose (bvw->priv->xine,
+					bvw->priv->vis);
+			bvw->priv->vis = NULL;
+		}
+	} else {
 		audio_source = xine_get_audio_source (bvw->priv->stream);
 		if (xine_post_wire_audio_port (audio_source,
 					bvw->priv->vis->audio_input[0]))
 			bvw->priv->using_vfx = TRUE;
-	} else if (has_video == FALSE && show_visuals == FALSE) {
-		audio_source = xine_get_audio_source (bvw->priv->stream);
-		if (xine_post_wire_audio_port (audio_source,
-					bvw->priv->ao_driver))
-			bvw->priv->using_vfx = FALSE;
 	}
 }
 
@@ -1958,6 +1987,7 @@ bacon_video_widget_open_with_subtitle (BaconVideoWidget *bvw, const char *mrl,
 	g_return_val_if_fail (bvw->priv->mrl == NULL, FALSE);
 
 	bvw->priv->got_redirect = FALSE;
+	bvw->priv->mrl = g_strdup (mrl);
 
 	if (subtitle_uri != NULL)
 	{
@@ -1974,6 +2004,12 @@ bacon_video_widget_open_with_subtitle (BaconVideoWidget *bvw, const char *mrl,
 		bacon_video_widget_close (bvw);
 		xine_error (bvw, error);
 		return FALSE;
+	} else {
+		xine_try_error (bvw, TRUE, error);
+		if (error != NULL && *error != NULL) {
+			bacon_video_widget_close (bvw);
+			return FALSE;
+		}
 	}
 
 	layer = xine_get_meta_info (bvw->priv->stream,
@@ -2033,8 +2069,6 @@ bacon_video_widget_open_with_subtitle (BaconVideoWidget *bvw, const char *mrl,
 
 	show_vfx_update (bvw, bvw->priv->show_vfx);
 
-	bvw->priv->mrl = g_strdup (mrl);
-
 	g_signal_emit (G_OBJECT (bvw),
 			bvw_table_signals[GOT_METADATA], 0, NULL);
 
@@ -2744,7 +2778,6 @@ bacon_video_widget_get_visuals_list (BaconVideoWidget *bvw)
 gboolean
 bacon_video_widget_set_visuals (BaconVideoWidget *bvw, const char *name)
 {
-	xine_post_t *newvis;
 	int speed;
 
 	g_return_val_if_fail (bvw != NULL, FALSE);
@@ -2774,31 +2807,11 @@ bacon_video_widget_set_visuals (BaconVideoWidget *bvw, const char *name)
 		return FALSE;
 	}
 
-	newvis = xine_post_init (bvw->priv->xine,
-			name, 0,
-			&bvw->priv->ao_driver, &bvw->priv->vo_driver);
-
-	if (newvis != NULL)
-	{
+	if (bvw->priv->using_vfx != FALSE) {
+		show_vfx_update (bvw, FALSE);
 		g_free (bvw->priv->vis_name);
 		bvw->priv->vis_name = g_strdup (name);
-
-		if (bvw->priv->vis != NULL)
-		{
-			xine_post_t *oldvis;
-
-			oldvis = bvw->priv->vis;
-			bvw->priv->vis = newvis;
-
-			if (bvw->priv->using_vfx != FALSE)
-			{
-				show_vfx_update (bvw, FALSE);
-				show_vfx_update (bvw, TRUE);
-			}
-			xine_post_dispose (bvw->priv->xine, oldvis);
-		} else {
-			bvw->priv->vis = newvis;
-		}
+		show_vfx_update (bvw, TRUE);
 	}
 
 	return FALSE;
