@@ -32,6 +32,7 @@
 #include <gnome.h>
 #include "totem-gromit.h"
 #else
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <stdlib.h>
@@ -52,10 +53,12 @@
 #include "totem-time-label.h"
 #include "totem-session.h"
 #include "totem-screenshot.h"
+#include "totem-sidebar.h"
 #include "totem-menu.h"
 #include "totem-options.h"
 #include "totem-uri.h"
 #include "totem-interface.h"
+#include "bacon-volume.h"
 #include "video-utils.h"
 
 #include "totem.h"
@@ -82,6 +85,9 @@
 
 #define ZOOM_IN_OFFSET 1
 #define ZOOM_OUT_OFFSET -1
+#define ZOOM_UPPER 200
+#define ZOOM_RESET 100
+#define ZOOM_LOWER 10
 
 #define FULLSCREEN_POPUP_TIMEOUT 5 * 1000
 
@@ -156,26 +162,34 @@ totem_action_save_size (Totem *totem)
 void
 totem_action_exit (Totem *totem)
 {
+	GdkDisplay *display = NULL;
+
 	if (gtk_main_level () > 0)
 		gtk_main_quit ();
 
 	if (totem == NULL)
 		exit (0);
 
+	if (totem->playlist != NULL)
+		gtk_widget_hide (GTK_WIDGET (totem->playlist));
+
+	if (totem->win != NULL) {
+		gtk_widget_hide (totem->win);
+		display = gtk_widget_get_display (totem->win);
+	}
+
 #ifndef HAVE_GTK_ONLY
 	totem_gromit_clear (TRUE);
 #endif /* !HAVE_GTK_ONLY */
+
+	if (display != NULL)
+		gdk_display_sync (display);
+
 	bacon_message_connection_free (totem->conn);
 	totem_action_save_size (totem);
 
 	totem_action_fullscreen (totem, FALSE);
 
-	if (totem->playlist)
-		gtk_widget_hide (GTK_WIDGET (totem->playlist));
-
-	if (totem->win)
-		gtk_widget_hide (totem->win);
-
 	totem_sublang_exit (totem);
 	totem_named_icons_dispose (totem);
 
@@ -206,18 +220,6 @@ totem_action_menu_popup (Totem *totem, guint button)
 			button, gtk_get_current_event_time ());
 }
 
-static void
-action_toggle_playlist (Totem *totem)
-{
-	GtkWidget *toggle;
-	gboolean state;
-
-	toggle = glade_xml_get_widget (totem->xml, "tmw_playlist_button");
-
-	state = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (toggle));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggle), !state);
-}
-
 static gboolean
 main_window_destroy_cb (GtkWidget *widget, GdkEvent *event, Totem *totem)
 {
@@ -365,7 +367,7 @@ totem_action_set_mrl_and_play (Totem *totem, const char *mrl)
 static gboolean
 totem_action_load_media (Totem *totem, MediaType type)
 {
-	const char **mrls;
+	char **mrls;
 	char *msg;
 
 	if (bacon_video_widget_can_play (totem->bvw, type) == FALSE)
@@ -385,17 +387,80 @@ totem_action_load_media (Totem *totem, MediaType type)
 		return FALSE;
 	}
 
-	totem_action_open_files (totem, (char **)mrls);
+	totem_action_open_files (totem, mrls);
+	g_strfreev (mrls);
+
 	return TRUE;
 }
 
+static gboolean
+totem_action_load_media_device (Totem *totem, const char *device)
+{
+	MediaType type;
+	GError *error = NULL;
+	char *device_path, *url;
+	gboolean retval;
+
+	if (g_str_has_prefix (device, "file://") != FALSE)
+		device_path = g_filename_from_uri (device, NULL, NULL);
+	else
+		device_path = g_strdup (device);
+
+	type = totem_cd_detect_type_with_url (device_path, &url, &error);
+
+	switch (type) {
+		case MEDIA_TYPE_ERROR:
+			totem_action_error ("Failed to play Audio/Video Disc",
+					    error ? error->message : "Reason unknown",
+					    totem);
+			retval = FALSE;
+			break;
+		case MEDIA_TYPE_DATA:
+			/* Set default location to the mountpoint of
+			 * this device */
+			{
+				char *s;
+				s = totem_action_open_dialog (totem, url, FALSE);
+				g_free (s);
+			}
+			retval = TRUE;
+			break;
+		case MEDIA_TYPE_DVD:
+		case MEDIA_TYPE_VCD:
+		case MEDIA_TYPE_CDDA:
+			bacon_video_widget_set_media_device
+				(BACON_VIDEO_WIDGET (totem->bvw), device_path);
+			totem_action_load_media (totem, type);
+			retval = TRUE;
+			break;
+		default:
+			g_assert_not_reached ();
+	}
+
+	g_free (url);
+	g_free (device_path);
+
+	return retval;
+}
+
+void
+totem_action_play_media_device (Totem *totem, const char *device)
+{
+	char *mrl;
+
+	if (totem_action_load_media_device (totem, device) != FALSE) {
+		mrl = totem_playlist_get_current_mrl (totem->playlist);
+		totem_action_set_mrl_and_play (totem, mrl);
+		g_free (mrl);
+	}
+}
+
 void
 totem_action_play_media (Totem *totem, MediaType type)
 {
 	char *mrl;
 
-	if (totem_action_load_media (totem, type) != FALSE)
-	{
+	if (totem_action_load_media (totem, type) != FALSE) {
 		mrl = totem_playlist_get_current_mrl (totem->playlist);
 		totem_action_set_mrl_and_play (totem, mrl);
 		g_free (mrl);
@@ -487,6 +552,7 @@ totem_action_fullscreen_toggle (Totem *totem)
 		bacon_video_widget_set_fullscreen (totem->bvw, TRUE);
 		bacon_video_widget_set_show_cursor (totem->bvw, FALSE);
 		gtk_window_fullscreen (GTK_WINDOW(totem->win));
+
 		if (bacon_video_widget_is_playing (totem->bvw) != FALSE)
 			totem_scrsaver_disable (totem->scr);
 
@@ -508,26 +574,33 @@ static char *
 totem_get_nice_name_for_stream (Totem *totem)
 {
 	char *title, *artist, *retval;
+	int tracknum;
 	GValue value = { 0, };
 
 	bacon_video_widget_get_metadata (totem->bvw, BVW_INFO_TITLE, &value);
-	title = g_strdup (g_value_get_string (&value));
+	title = g_value_dup_string (&value);
 	g_value_unset (&value);
 
 	if (title == NULL)
 		return NULL;
 
 	bacon_video_widget_get_metadata (totem->bvw, BVW_INFO_ARTIST, &value);
-	artist = g_strdup (g_value_get_string (&value));
+	artist = g_value_dup_string (&value);
 	g_value_unset (&value);
 
 	if (artist == NULL)
-	{
-		g_free (title);
-		return NULL;
-	}
+		return title;
 
-	retval = g_strdup_printf ("%s - %s", artist, title);
+	bacon_video_widget_get_metadata (totem->bvw, BVW_INFO_TRACK_NUMBER,
+			&value);
+	tracknum = g_value_get_int (&value);
+
+	if (tracknum != 0) {
+		retval = g_strdup_printf ("%02d. %s - %s",
+				tracknum, artist, title);
+	} else {
+		retval = g_strdup_printf ("%s - %s", artist, title);
+	}
 	g_free (artist);
 	g_free (title);
 
@@ -567,15 +640,11 @@ update_mrl_label (Totem *totem, const char *name)
 
 		widget = glade_xml_get_widget (totem->xml, "tcw_title_label");
 		gtk_label_set_markup (GTK_LABEL (widget), text);
-		widget = glade_xml_get_widget (totem->xml, "tmw_title_label");
-		gtk_label_set_markup (GTK_LABEL (widget), text);
 
 		g_free (text);
 
 		/* Title */
-		text = g_strdup_printf (_("%s - Totem Movie Player"), name);
-		gtk_window_set_title (GTK_WINDOW (totem->win), text);
-		g_free (text);
+		gtk_window_set_title (GTK_WINDOW (totem->win), name);
 	} else {
 		totem_statusbar_set_time_and_length (TOTEM_STATUSBAR
 				(totem->statusbar), 0, 0);
@@ -590,8 +659,6 @@ update_mrl_label (Totem *totem, const char *name)
 			 _("No File"));
 		widget = glade_xml_get_widget (totem->xml, "tcw_title_label");
 		gtk_label_set_markup (GTK_LABEL (widget), text);
-		widget = glade_xml_get_widget (totem->xml, "tmw_title_label");
-		gtk_label_set_markup (GTK_LABEL (widget), text);
 
 		g_free (text);
 
@@ -604,7 +671,6 @@ gboolean
 totem_action_set_mrl_with_warning (Totem *totem, const char *mrl,
 		gboolean warn)
 {
-	GtkWidget *widget;
 	gboolean retval = TRUE;
 
 	if (totem->mrl != NULL)
@@ -615,58 +681,40 @@ totem_action_set_mrl_with_warning (Totem *totem, const char *mrl,
 	}
 
 	/* Reset the properties and wait for the signal*/
-	bacon_video_widget_properties_update
-		(BACON_VIDEO_WIDGET_PROPERTIES (totem->properties),
-		 totem->bvw, TRUE);
+	bacon_video_widget_properties_reset
+		(BACON_VIDEO_WIDGET_PROPERTIES (totem->properties));
 
 	if (mrl == NULL)
 	{
 		retval = FALSE;
 
-		gtk_window_set_title (GTK_WINDOW (totem->win), _("Totem"));
-
 		/* Play/Pause */
 		gtk_widget_set_sensitive (totem->pp_button, FALSE);
-		widget = glade_xml_get_widget (totem->xml, "tmw_play_menu_item");
-		gtk_widget_set_sensitive (widget, FALSE);
 
-		widget = glade_xml_get_widget (totem->xml_popup, "trcm_play");
-		gtk_widget_set_sensitive (widget, FALSE);
+		totem_main_set_sensitivity ("tmw_play_menu_item", FALSE);
+		totem_popup_set_sensitivity ("trcm_play", FALSE);
 
 		/* Seek bar and seek buttons */
 		update_seekable (totem, FALSE);
 
 		/* Volume */
-		widget = glade_xml_get_widget (totem->xml, "tmw_volume_hbox");
-		gtk_widget_set_sensitive (widget, FALSE);
-		widget = glade_xml_get_widget (totem->xml, "tmw_volume_up_menu_item");
-		gtk_widget_set_sensitive (widget, FALSE);
-		widget = glade_xml_get_widget (totem->xml, "tmw_volume_down_menu_item");
-		gtk_widget_set_sensitive (widget, FALSE);
-		widget = glade_xml_get_widget (totem->xml_popup, "trcm_volume_up");
-		gtk_widget_set_sensitive (widget, FALSE);
-		widget = glade_xml_get_widget (totem->xml_popup, "trcm_volume_down");
-		gtk_widget_set_sensitive (widget, FALSE);
+		totem_main_set_sensitivity ("tcw_volume_button", FALSE);
+		totem_main_set_sensitivity ("tmw_volume_up_menu_item", FALSE);
+		totem_main_set_sensitivity ("tmw_volume_down_menu_item", FALSE);
+		totem_popup_set_sensitivity ("trcm_volume_up", FALSE);
+		totem_popup_set_sensitivity ("trcm_volume_down", FALSE);
 
 		/* Control popup */
 		gtk_widget_set_sensitive (totem->fs_seek, FALSE);
 		gtk_widget_set_sensitive (totem->fs_pp_button, FALSE);
-		widget = glade_xml_get_widget (totem->xml,
-				"tcw_previous_button");
-		gtk_widget_set_sensitive (widget, FALSE);
-		widget = glade_xml_get_widget (totem->xml, "tcw_next_button"); 
-		gtk_widget_set_sensitive (widget, FALSE);
-		widget = glade_xml_get_widget (totem->xml_popup, "trcm_next_chapter");
-		gtk_widget_set_sensitive (widget, FALSE);
-		widget = glade_xml_get_widget (totem->xml_popup, "trcm_previous_chapter");
-		gtk_widget_set_sensitive (widget, FALSE);
-		widget = glade_xml_get_widget (totem->xml, "tcw_volume_hbox");
-		gtk_widget_set_sensitive (widget, FALSE);
+		totem_main_set_sensitivity ("tcw_previous_button", FALSE);
+		totem_main_set_sensitivity ("tcw_next_button", FALSE);
+		totem_popup_set_sensitivity ("trcm_next_chapter", FALSE);
+		totem_popup_set_sensitivity ("trcm_previous_chapter", FALSE);
+		totem_main_set_sensitivity ("tcw_volume_hbox", FALSE);
 
 		/* Take a screenshot */
-		widget = glade_xml_get_widget (totem->xml,
-				"tmw_take_screenshot_menu_item");
-		gtk_widget_set_sensitive (widget, FALSE);
+		totem_main_set_sensitivity ("tmw_take_screenshot_menu_item", FALSE);
 
 		/* Set the logo */
 		bacon_video_widget_set_logo_mode (totem->bvw, TRUE);
@@ -690,11 +738,9 @@ totem_action_set_mrl_with_warning (Totem *totem, const char *mrl,
 		totem->mrl = g_strdup (mrl);
 
 		/* Play/Pause */
+		totem_main_set_sensitivity ("tmw_play_menu_item", TRUE);
 		gtk_widget_set_sensitive (totem->pp_button, TRUE);
-		widget = glade_xml_get_widget (totem->xml, "tmw_play_menu_item");
-		gtk_widget_set_sensitive (widget, TRUE);
-		widget = glade_xml_get_widget (totem->xml_popup, "trcm_play");
-		gtk_widget_set_sensitive (widget, TRUE);
+		totem_popup_set_sensitivity ("trcm_play", TRUE);
 		gtk_widget_set_sensitive (totem->fs_pp_button, TRUE);
 
 		/* Seek bar */
@@ -703,23 +749,16 @@ totem_action_set_mrl_with_warning (Totem *totem, const char *mrl,
 
 		/* Volume */
 		caps = bacon_video_widget_can_set_volume (totem->bvw);
-		widget = glade_xml_get_widget (totem->xml, "tmw_volume_hbox");
-		gtk_widget_set_sensitive (widget, caps);
-		widget = glade_xml_get_widget (totem->xml, "tmw_volume_up_menu_item");
-		gtk_widget_set_sensitive (widget, caps);
-		widget = glade_xml_get_widget (totem->xml, "tmw_volume_down_menu_item");
-		gtk_widget_set_sensitive (widget, caps);
-		widget = glade_xml_get_widget (totem->xml, "tcw_volume_hbox");
-		gtk_widget_set_sensitive (widget, caps);
-		widget = glade_xml_get_widget (totem->xml_popup, "trcm_volume_up");                gtk_widget_set_sensitive (widget, caps);
-		widget = glade_xml_get_widget (totem->xml_popup, "trcm_volume_down");
-		gtk_widget_set_sensitive (widget, caps);
-
+		totem_main_set_sensitivity ("tcw_volume_button", caps);
+		totem_main_set_sensitivity ("tcw_volume_hbox", caps);
+		totem_popup_set_sensitivity ("trcm_volume_up", caps);
+		totem_popup_set_sensitivity ("trcm_volume_down", caps);
+		totem_main_set_sensitivity ("tmw_volume_up_menu_item", caps);
+		totem_main_set_sensitivity ("tmw_volume_down_menu_item", caps);
 
 		/* Take a screenshot */
-		widget = glade_xml_get_widget (totem->xml,
-				"tmw_take_screenshot_menu_item");
-		gtk_widget_set_sensitive (widget, retval);
+		totem_main_set_sensitivity ("tmw_take_screenshot_menu_item",
+				retval);
 
 		/* Set the playlist */
 		totem_playlist_set_playing (totem->playlist, retval);
@@ -746,8 +785,7 @@ totem_action_set_mrl_with_warning (Totem *totem, const char *mrl,
 	update_buttons (totem);
 	update_media_menu_items (totem);
 
-	widget = glade_xml_get_widget (totem->xml, "tmw_properties_menu_item");
-	gtk_widget_set_sensitive (widget, retval);
+	totem_main_set_sensitivity ("tmw_properties_menu_item", retval);
 
 	return retval;
 }
@@ -845,19 +883,42 @@ totem_action_seek_relative (Totem *totem, int off_sec)
 	}
 }
 
+static void
+totem_action_zoom (Totem *totem, int zoom)
+{
+	if (zoom < ZOOM_LOWER || zoom > ZOOM_UPPER)
+		return;
+
+	bacon_video_widget_set_zoom (totem->bvw, zoom);
+
+	if (zoom == ZOOM_UPPER) {
+		totem_main_set_sensitivity ("tmw_zoom_in_menu_item", FALSE);
+	} else if (zoom == ZOOM_LOWER) {
+		totem_main_set_sensitivity ("tmw_zoom_out_menu_item", FALSE);
+	} else if (zoom == ZOOM_RESET) {
+		totem_main_set_sensitivity ("tmw_zoom_reset_menu_item", FALSE);
+		totem_main_set_sensitivity ("tmw_zoom_in_menu_item", TRUE);
+		totem_main_set_sensitivity ("tmw_zoom_out_menu_item", TRUE);
+	} else {
+		totem_main_set_sensitivity ("tmw_zoom_in_menu_item", TRUE);
+		totem_main_set_sensitivity ("tmw_zoom_out_menu_item", TRUE);
+		totem_main_set_sensitivity ("tmw_zoom_reset_menu_item", TRUE);
+	}
+}
+
 static void
 totem_action_zoom_relative (Totem *totem, int off_pct)
 {
 	int zoom;
 
 	zoom = bacon_video_widget_get_zoom (totem->bvw);
-	bacon_video_widget_set_zoom (totem->bvw, zoom + off_pct);
+	totem_action_zoom (totem, zoom + off_pct);
 }
 
 static void
 totem_action_zoom_reset (Totem *totem)
 {
-	bacon_video_widget_set_zoom (totem->bvw, 100);
+	totem_action_zoom (totem, 100);
 }
 
 void
@@ -919,7 +980,7 @@ totem_action_drop_files (Totem *totem, GtkSelectionData *data,
 	GList *list, *p, *file_list;
 	gboolean cleared = FALSE;
 
-	list = gnome_vfs_uri_list_parse (data->data);
+	list = gnome_vfs_uri_list_parse ((const char *)data->data);
 
 	if (list == NULL)
 		return FALSE;
@@ -936,11 +997,14 @@ totem_action_drop_files (Totem *totem, GtkSelectionData *data,
 	}
 
 	gnome_vfs_uri_list_free (list);
-	file_list = g_list_reverse (file_list);
-
 	if (file_list == NULL)
 		return FALSE;
 
+	if (drop_type != 1)
+		file_list = g_list_sort (file_list, (GCompareFunc) strcmp);
+	else
+		file_list = g_list_reverse (file_list);
+
 	for (p = file_list; p != NULL; p = p->next)
 	{
 		char *filename, *title;
@@ -1083,18 +1147,6 @@ on_next_button_clicked (GtkButton *button, Totem *totem)
 	TOTEM_PROFILE (totem_action_next (totem));
 }
 
-static void
-on_playlist_button_toggled (GtkToggleButton *button, Totem *totem)
-{
-	gboolean state;
-
-	state = gtk_toggle_button_get_active (button);
-	if (state != FALSE)
-		gtk_widget_show (GTK_WIDGET (totem->playlist));
-	else
-		gtk_widget_hide (GTK_WIDGET (totem->playlist));
-}
-
 static void
 on_got_redirect (BaconVideoWidget *bvw, const char *mrl, Totem *totem)
 {
@@ -1119,34 +1171,58 @@ on_channels_change_event (BaconVideoWidget *bvw, Totem *totem)
 	totem_sublang_update (totem);
 }
 
+static void
+on_playlist_change_name (TotemPlaylist *playlist, Totem *totem)
+{
+	char *name, *artist, *album, *title;
+	gboolean cur;
+
+	if ((name = totem_playlist_get_current_title (playlist,
+						      &cur)) != NULL) {
+		update_mrl_label (totem, name);
+		g_free (name);
+	}
+
+	if (totem_playlist_get_current_metadata (playlist, &artist,
+						 &title, &album) != FALSE) {
+		bacon_video_widget_properties_from_metadata (
+			BACON_VIDEO_WIDGET_PROPERTIES (totem->properties),
+			artist, title, album);
+
+		g_free (artist);
+		g_free (album);
+		g_free (title);
+	}
+}
+
 static void
 on_got_metadata_event (BaconVideoWidget *bvw, Totem *totem)
 {
         char *name = NULL;
-	gboolean custom;
 
         bacon_video_widget_properties_update
 		(BACON_VIDEO_WIDGET_PROPERTIES (totem->properties),
-		 totem->bvw, FALSE);
+		 totem->bvw);
 
 	name = totem_get_nice_name_for_stream (totem);
 
-	if (name == NULL)
-	{
-		name = totem_playlist_get_current_title
-			(totem->playlist, &custom);
-		custom = TRUE;
-	} else {
-		custom = FALSE;
-	}
-
-	update_mrl_label (totem, name);
-
-	if (custom == FALSE)
+	if (name != NULL) {
 		totem_playlist_set_title
 			(TOTEM_PLAYLIST (totem->playlist), name);
+		g_free (name);
+	} else {
+		GValue v = { 0 };
+		const gchar *cdid;
 
-	g_free (name);
+		bacon_video_widget_get_metadata (totem->bvw, BVW_INFO_CDINDEX, &v);
+		if ((cdid = g_value_get_string (&v)) != NULL) {
+			totem_playlist_set_cdindex
+				(TOTEM_PLAYLIST (totem->playlist), cdid);
+		}
+		on_playlist_change_name
+			(TOTEM_PLAYLIST (totem->playlist), totem);
+		g_value_unset (&v);
+	}
 }
 
 static void
@@ -1157,9 +1233,9 @@ on_error_event (BaconVideoWidget *bvw, char *message,
 		play_pause_set_label (totem, STATE_STOPPED);
 
 	if (fatal == FALSE) {
-		totem_action_error (_("An error occured"), message, totem);
+		totem_action_error (_("An error occurred"), message, totem);
 	} else {
-		totem_action_error_and_exit (_("An error occured"),
+		totem_action_error_and_exit (_("An error occurred"),
 				message, totem);
 	}
 }
@@ -1179,8 +1255,6 @@ on_buffering_event (BaconVideoWidget *bvw, int percentage, Totem *totem)
 static void
 update_seekable (Totem *totem, gboolean seekable)
 {
-	GtkWidget *widget;
-
 	if (totem->seekable == seekable)
 		return;
 
@@ -1190,25 +1264,15 @@ update_seekable (Totem *totem, gboolean seekable)
 	gtk_widget_set_sensitive (totem->seek, seekable);
 	gtk_widget_set_sensitive (totem->fs_seek, seekable);
 
-	widget = glade_xml_get_widget (totem->xml, "tmw_seek_hbox");
-	gtk_widget_set_sensitive (widget, seekable);
+	totem_main_set_sensitivity ("tmw_seek_hbox", seekable);
 
-	widget = glade_xml_get_widget (totem->xml, "tcw_time_hbox");
-	gtk_widget_set_sensitive (widget, seekable);
+	totem_main_set_sensitivity ("tcw_time_hbox", seekable);
 
-	widget = glade_xml_get_widget (totem->xml,
-			"tmw_skip_forward_menu_item");
-	gtk_widget_set_sensitive (widget, seekable);
-	widget = glade_xml_get_widget (totem->xml,
-			"tmw_skip_backwards_menu_item");
-	gtk_widget_set_sensitive (widget, seekable);
-	widget = glade_xml_get_widget (totem->xml_popup, "trcm_skip_forward");
-	gtk_widget_set_sensitive (widget, seekable);
-	widget = glade_xml_get_widget (totem->xml_popup,
-			"trcm_skip_backwards");
-	gtk_widget_set_sensitive (widget, seekable);
-	widget = glade_xml_get_widget (totem->xml, "tmw_skip_to_menu_item");
-	gtk_widget_set_sensitive (widget, seekable);
+	totem_main_set_sensitivity ("tmw_skip_forward_menu_item", seekable);
+	totem_main_set_sensitivity ("tmw_skip_backwards_menu_item", seekable);
+	totem_popup_set_sensitivity ("trcm_skip_forward", seekable);
+	totem_popup_set_sensitivity ("trcm_skip_backwards", seekable);
+	totem_main_set_sensitivity ("tmw_skip_to_menu_item", seekable);
 	if (totem->skipto)
 		totem_skipto_set_seekable (totem->skipto, seekable);
 }
@@ -1225,6 +1289,11 @@ update_current_time (BaconVideoWidget *bvw,
 
 	if (totem->seek_lock == FALSE)
 	{
+		gtk_adjustment_set_value (totem->seekadj,
+				current_position * 65535);
+		gtk_adjustment_set_value (totem->fs_seekadj,
+				current_position * 65535);
+
 		if (stream_length == 0 && totem->mrl != NULL)
 		{
 			totem_statusbar_set_time_and_length
@@ -1237,14 +1306,12 @@ update_current_time (BaconVideoWidget *bvw,
 				(int) (stream_length / 1000));
 		}
 
-		gtk_adjustment_set_value (totem->seekadj,
-				current_position * 65535);
-		gtk_adjustment_set_value (totem->fs_seekadj,
-				current_position * 65535);
-
 		totem_time_label_set_time
 			(TOTEM_TIME_LABEL (totem->tcw_time_label),
 			 current_time, stream_length);
+		bacon_video_widget_properties_from_time
+			(BACON_VIDEO_WIDGET_PROPERTIES (totem->properties),
+			 stream_length);
 	}
 }
 
@@ -1273,8 +1340,8 @@ update_volume_sliders (Totem *totem)
 				totem->prev_volume != -1 && volume != -1))
 	{
 		totem->volume_first_time = 0;
-		gtk_adjustment_set_value (totem->voladj,
-				(float) volume);
+		bacon_volume_button_set_value (
+			BACON_VOLUME_BUTTON (totem->volume), (float) volume);
 		gtk_adjustment_set_value (totem->fs_voladj,
 				(float) volume);
 	}
@@ -1354,35 +1421,22 @@ vol_cb (GtkWidget *widget, Totem *totem)
 				(totem->bvw, (gint) totem->fs_voladj->value);
 
 			/* Update the fullscreen volume adjustment */
-			gtk_adjustment_set_value (totem->voladj, 
-					gtk_adjustment_get_value
-					(totem->fs_voladj));
+			bacon_volume_button_set_value (
+				BACON_VOLUME_BUTTON (totem->volume),
+				gtk_adjustment_get_value (totem->fs_voladj));
 		} else {
-			bacon_video_widget_set_volume
-				(totem->bvw, (gint) totem->voladj->value);
-			/* Update the volume adjustment */
-			gtk_adjustment_set_value (totem->fs_voladj, 
-					gtk_adjustment_get_value
-					(totem->voladj));
+			int value = bacon_volume_button_get_value (
+				BACON_VOLUME_BUTTON (totem->volume));
 
+			bacon_video_widget_set_volume (totem->bvw, value);
+			/* Update the volume adjustment */
+			gtk_adjustment_set_value (totem->fs_voladj, value);
 		}
 
 		totem->vol_lock = FALSE;
 	}
 }
 
-static void
-totem_add_cd_track_name (Totem *totem, const char *filename)
-{
-	char *name;
-
-	bacon_video_widget_open (totem->bvw, filename, NULL);
-	name = totem_get_nice_name_for_stream (totem);
-	bacon_video_widget_close (totem->bvw);
-	totem_playlist_add_mrl (totem->playlist, filename, name);
-	g_free (name);
-}
-
 static gboolean
 totem_action_open_files (Totem *totem, char **list)
 {
@@ -1444,15 +1498,10 @@ totem_action_open_files_list (Totem *totem, GSList *list)
 				cleared = TRUE;
 			}
 
-			if (strcmp (data, "dvd:") == 0)
-			{
-				totem_action_load_media (totem, MEDIA_TYPE_DVD);
-			} else if (strcmp (data, "vcd:") == 0) {
-				totem_action_load_media (totem, MEDIA_TYPE_VCD);
-			} else if (strcmp (data, "cd:") == 0) {
-				totem_action_load_media (totem, MEDIA_TYPE_CDDA);
+			if (totem_is_block_device (filename) != FALSE) {
+				totem_action_load_media_device (totem, data);
 			} else if (strstr (filename, "cdda:/") != NULL) {
-				totem_add_cd_track_name (totem, filename);
+				totem_playlist_add_mrl (totem->playlist, data, NULL);
 			} else if (totem_playlist_add_mrl (totem->playlist,
 						filename, NULL) != FALSE) {
 				totem_action_add_recent (totem, filename);
@@ -1473,12 +1522,12 @@ totem_action_open_files_list (Totem *totem, GSList *list)
 	return cleared;
 }
 
-static void
-on_open1_activate (GtkButton *button, Totem *totem)
+char *
+totem_action_open_dialog (Totem *totem, const char *path, gboolean play)
 {
 	GtkWidget *fs;
 	int response;
-	static char *path = NULL;
+	char *path_new = NULL;
 
 	fs = gtk_file_chooser_dialog_new (_("Select Files"),
 			GTK_WINDOW (totem->win), GTK_FILE_CHOOSER_ACTION_OPEN,
@@ -1499,7 +1548,6 @@ on_open1_activate (GtkButton *button, Totem *totem)
 	while (1)
 	{
 		GSList *filenames;
-		char *mrl;
 		gboolean playlist_modified;
 
 		response = gtk_dialog_run (GTK_DIALOG (fs));
@@ -1524,21 +1572,36 @@ on_open1_activate (GtkButton *button, Totem *totem)
 
 		/* Save the path */
 		if (filenames->data != NULL)
-		{
-			g_free (path);
-			path = g_path_get_dirname (filenames->data);
-		}
+			path_new = g_path_get_dirname (filenames->data);
 
 		g_slist_foreach (filenames, (GFunc) g_free, NULL);
 		g_slist_free (filenames);
 
-		mrl = totem_playlist_get_current_mrl (totem->playlist);
-		totem_action_set_mrl_and_play (totem, mrl);
-		g_free (mrl);
+		if (play != FALSE) {
+			char *mrl;
+
+			mrl = totem_playlist_get_current_mrl (totem->playlist);
+			totem_action_set_mrl_and_play (totem, mrl);
+			g_free (mrl);
+		}
 		break;
 	}
 
 	gtk_widget_destroy (fs);
+	return path_new;
+}
+
+static void
+on_open1_activate (GtkButton *button, Totem *totem)
+{
+	static char *path = NULL;
+	char *new_path;
+
+	new_path = totem_action_open_dialog (totem, path, TRUE);
+	if (new_path != NULL) {
+		g_free (path);
+		path = new_path;
+	}
 }
 
 //FIXME move the URI to a separate widget
@@ -1576,9 +1639,10 @@ on_open_location1_activate (GtkButton *button, Totem *totem)
 			mrl = totem_playlist_get_current_mrl (totem->playlist);
 			totem_action_set_mrl_and_play (totem, mrl);
 			g_free (mrl);
-
+#ifndef HAVE_GTK_ONLY
 			gnome_entry_append_history (GNOME_ENTRY (gentry),
 					TRUE, uri);
+#endif /* !HAVE_GTK_ONLY */
 		}
 	}
 
@@ -1670,12 +1734,6 @@ on_aspect_ratio_dvb_activate (GtkButton *button, Totem *totem)
 	totem_action_set_aspect_ratio (totem, BVW_RATIO_DVB);
 }
 
-static void
-on_show_playlist1_activate (GtkButton *button, Totem *totem)
-{
-	action_toggle_playlist (totem);
-}
-
 static void
 on_fs_exit1_activate (GtkButton *button, Totem *totem)
 {
@@ -1705,7 +1763,7 @@ on_shuffle_mode1_toggled (GtkCheckMenuItem *checkmenuitem, Totem *totem)
 static void
 on_always_on_top1_activate (GtkCheckMenuItem *checkmenuitem, Totem *totem)
 {
-	totem_gdk_window_set_always_on_top (GTK_WIDGET (totem->win)->window,
+	gtk_window_set_keep_above (GTK_WINDOW (totem->win),
 			gtk_check_menu_item_get_active (checkmenuitem));
 	gconf_client_set_bool (totem->gc,
 			GCONF_PREFIX"/window_on_top",
@@ -1718,6 +1776,9 @@ show_controls (Totem *totem, gboolean was_fullscreen)
 	GtkWidget *menubar, *controlbar, *statusbar, *item, *bvw_vbox, *widget;
 	int width = 0, height = 0;
 
+	if (totem->bvw == NULL)
+		return;
+
 	menubar = glade_xml_get_widget (totem->xml, "tmw_menubar");
 	controlbar = glade_xml_get_widget (totem->xml, "tmw_controls_vbox");
 	statusbar = glade_xml_get_widget (totem->xml, "tmw_statusbar");
@@ -1736,6 +1797,11 @@ show_controls (Totem *totem, gboolean was_fullscreen)
 		gtk_widget_show (menubar);
 		gtk_widget_show (controlbar);
 		gtk_widget_show (statusbar);
+		if (totem_sidebar_is_visible (totem) != FALSE)
+			gtk_widget_show (totem->sidebar);
+		else
+			gtk_widget_hide (totem->sidebar);
+
 		gtk_widget_hide (item);
 		gtk_container_set_border_width (GTK_CONTAINER (bvw_vbox),
 				BVW_VBOX_BORDER_WIDTH);
@@ -1755,6 +1821,7 @@ show_controls (Totem *totem, gboolean was_fullscreen)
 		gtk_widget_hide (menubar);
 		gtk_widget_hide (controlbar);
 		gtk_widget_hide (statusbar);
+		gtk_widget_hide (totem->sidebar);
 
 		 /* We won't show controls in fullscreen */
 		if (totem_is_fullscreen (totem) != FALSE)
@@ -2152,7 +2219,7 @@ totem_action_remote (Totem *totem, TotemRemoteCommand cmd, const char *url)
 		} else if (g_str_has_prefix (url, "cd:") != FALSE) {
 			totem_action_play_media (totem, MEDIA_TYPE_CDDA);
 		} else if (g_str_has_prefix (url, "cdda:/") != FALSE) {
-			totem_add_cd_track_name (totem, url);
+			totem_playlist_add_mrl (totem->playlist, url, NULL);
 		} else if (totem_playlist_add_mrl (totem->playlist,
 					url, NULL) != FALSE) {
 			totem_action_add_recent (totem, url);
@@ -2174,13 +2241,27 @@ totem_action_remote (Totem *totem, TotemRemoteCommand cmd, const char *url)
 			gtk_check_menu_item_set_active (item, !value);
 		}
 		break;
+	case TOTEM_REMOTE_COMMAND_SHOW_PLAYING:
+		{
+			char *title;
+			gboolean custom;
+
+			title = totem_playlist_get_current_title
+				(totem->playlist, &custom);
+			bacon_message_connection_send (totem->conn,
+					title ? title : SHOW_PLAYING_NO_TRACKS);
+			g_free (title);
+		}
+		break;
 	default:
 		handled = FALSE;
 		break;
 	}
 
-	if (handled != FALSE)
+	if (handled != FALSE &&
+			gtk_window_is_active (GTK_WINDOW (totem->win))) {
 		on_video_motion_notify_event (NULL, NULL, totem);
+	}
 }
 
 #ifdef HAVE_REMOTE
@@ -2192,17 +2273,6 @@ totem_button_pressed_remote_cb (TotemRemote *remote, TotemRemoteCommand cmd,
 }
 #endif /* HAVE_REMOTE */
 
-static int
-toggle_playlist_from_playlist (GtkWidget *playlist, int trash, Totem *totem)
-{
-	GtkWidget *button;
-
-	button = glade_xml_get_widget (totem->xml, "tmw_playlist_button");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), FALSE);
-
-	return TRUE;
-}
-
 static void
 playlist_changed_cb (GtkWidget *playlist, Totem *totem)
 {
@@ -2283,10 +2353,12 @@ playlist_shuffle_toggle_cb (TotemPlaylist *playlist, gboolean shuffle, Totem *to
 static void
 update_fullscreen_size (Totem *totem)
 {
-	gdk_screen_get_monitor_geometry (gdk_screen_get_default (),
+	GdkScreen *screen;
+
+	screen = gtk_window_get_screen (GTK_WINDOW (totem->win));
+	gdk_screen_get_monitor_geometry (screen,
 			gdk_screen_get_monitor_at_window
-			(gdk_screen_get_default (),
-			 totem->win->window),
+			(screen, totem->win->window),
 			&totem->fullscreen_rect);
 }
 
@@ -2302,6 +2374,8 @@ move_popups (Totem *totem)
 	int control_width, control_height;
 	int exit_width, exit_height;
 
+	update_fullscreen_size (totem);
+
 	gtk_window_get_size (GTK_WINDOW (totem->control_popup),
 			&control_width, &control_height);
 	gtk_window_get_size (GTK_WINDOW (totem->exit_popup),
@@ -2319,23 +2393,20 @@ move_popups (Totem *totem)
 				totem->fullscreen_rect.y);
 		gtk_window_move (GTK_WINDOW (totem->control_popup),
 				totem->fullscreen_rect.width - control_width,
-				totem->fullscreen_rect.height
-				- control_height);
+				totem->fullscreen_rect.height + totem->fullscreen_rect.y - control_height);
 	} else {
 		gtk_window_move (GTK_WINDOW (totem->exit_popup),
-				totem->fullscreen_rect.width - exit_width,
+				totem->fullscreen_rect.width + totem->fullscreen_rect.x - exit_width,
 				totem->fullscreen_rect.y);
 		gtk_window_move (GTK_WINDOW (totem->control_popup),
 				totem->fullscreen_rect.x,
-				totem->fullscreen_rect.height
-				- control_height);
+				totem->fullscreen_rect.height + totem->fullscreen_rect.y - control_height);
 	}
 }
 
 static void
 size_changed_cb (GdkScreen *screen, Totem *totem)
 {
-	update_fullscreen_size (totem);
 	move_popups (totem);
 }
 
@@ -2401,8 +2472,6 @@ on_video_motion_notify_event (GtkWidget *widget, GdkEventMotion *event,
 
 	item = glade_xml_get_widget (totem->xml, "tcw_hbox");
 	gtk_widget_show_all (item);
-	item = glade_xml_get_widget (totem->xml, "tmw_title_label");
-	gtk_widget_realize (item);
 	gdk_flush ();
 
 	move_popups (totem);
@@ -2538,11 +2607,7 @@ totem_action_handle_key (Totem *totem, GdkEventKey *event)
 #endif /* HAVE_XFREE */
 	case GDK_p:
 	case GDK_P:
-		/* Playlist keyboard shortcut? */
-		if (event->state & GDK_CONTROL_MASK)
-			action_toggle_playlist (totem);
-		else
-			totem_action_play_pause (totem);
+		totem_action_play_pause (totem);
 		break;
 	case GDK_q:
 	case GDK_Q:
@@ -2670,14 +2735,12 @@ totem_action_handle_volume_scroll (Totem *totem, GdkScrollDirection direction)
 static int
 on_window_key_press_event (GtkWidget *win, GdkEventKey *event, Totem *totem)
 {
-	/* Special case the Playlist, Eject, Open, Open URI and
+	/* Special case Eject, Open, Open URI and
 	 * seeking keyboard shortcuts */
 	if (event->state != 0
 			&& (event->state & GDK_CONTROL_MASK))
 	{
 		switch (event->keyval)
-		case GDK_p:
-		case GDK_P:
 		case GDK_E:
 		case GDK_e:
 		case GDK_O:
@@ -2718,32 +2781,24 @@ on_volume_scroll_event (GtkWidget *win, GdkEventScroll *event, Totem *totem)
 static void
 update_media_menu_items (Totem *totem)
 {
-        GtkWidget *item;
         gboolean playing;
 
 	playing = totem_playing_dvd (totem->mrl);
 
-	item = glade_xml_get_widget (totem->xml, "tmw_dvd_root_menu_item");
-	gtk_widget_set_sensitive (item, playing);
-        item = glade_xml_get_widget (totem->xml, "tmw_dvd_title_menu_item");
-	gtk_widget_set_sensitive (item, playing);
-        item = glade_xml_get_widget (totem->xml, "tmw_dvd_audio_menu_item");
-	gtk_widget_set_sensitive (item, playing);
-        item = glade_xml_get_widget (totem->xml, "tmw_dvd_angle_menu_item");
-	gtk_widget_set_sensitive (item, playing);
-        item = glade_xml_get_widget (totem->xml, "tmw_dvd_chapter_menu_item");
-	gtk_widget_set_sensitive (item, playing);
+	totem_main_set_sensitivity ("tmw_dvd_root_menu_item", playing);
+	totem_main_set_sensitivity ("tmw_dvd_title_menu_item", playing);
+	totem_main_set_sensitivity ("tmw_dvd_audio_menu_item", playing);
+	totem_main_set_sensitivity ("tmw_dvd_angle_menu_item", playing);
+	totem_main_set_sensitivity ("tmw_dvd_chapter_menu_item", playing);
 
 	playing = totem_is_media (totem->mrl);
 
-	item = glade_xml_get_widget (totem->xml, "tmw_eject_menu_item");
-	gtk_widget_set_sensitive (item, playing);
+	totem_main_set_sensitivity ("tmw_eject_menu_item", playing);
 }
 
 static void
 update_buttons (Totem *totem)
 {
-	GtkWidget *item;
 	gboolean has_item;
 
 	/* Previous */
@@ -2755,15 +2810,10 @@ update_buttons (Totem *totem)
 		has_item = totem_playlist_has_previous_mrl (totem->playlist);
 	}
 
-	item = glade_xml_get_widget (totem->xml, "tmw_previous_button");
-	gtk_widget_set_sensitive (item, has_item);
-	item = glade_xml_get_widget (totem->xml, "tcw_previous_button");
-	gtk_widget_set_sensitive (item, has_item);
-	item = glade_xml_get_widget (totem->xml,
-			"tmw_previous_chapter_menu_item");
-	gtk_widget_set_sensitive (item, has_item);
-	item = glade_xml_get_widget (totem->xml_popup, "trcm_previous_chapter");
-	gtk_widget_set_sensitive (item, has_item);
+	totem_main_set_sensitivity ("tmw_previous_button", has_item);
+	totem_main_set_sensitivity ("tcw_previous_button", has_item);
+	totem_main_set_sensitivity ("tmw_previous_chapter_menu_item", has_item);
+	totem_popup_set_sensitivity ("trcm_previous_chapter", has_item);
 
 	/* Next */
 	/* FIXME Need way to detect if DVD Title has no more chapters */
@@ -2774,14 +2824,10 @@ update_buttons (Totem *totem)
 		has_item = totem_playlist_has_next_mrl (totem->playlist);
 	}
 
-	item = glade_xml_get_widget (totem->xml, "tmw_next_button");
-	gtk_widget_set_sensitive (item, has_item);
-	item = glade_xml_get_widget (totem->xml, "tcw_next_button");
-	gtk_widget_set_sensitive (item, has_item);
-	item = glade_xml_get_widget (totem->xml, "tmw_next_chapter_menu_item");
-	gtk_widget_set_sensitive (item, has_item);
-	item = glade_xml_get_widget (totem->xml_popup, "trcm_next_chapter");
-	gtk_widget_set_sensitive (item, has_item);
+	totem_main_set_sensitivity ("tmw_next_button", has_item);
+	totem_main_set_sensitivity ("tcw_next_button", has_item);
+	totem_main_set_sensitivity ("tmw_next_chapter_menu_item", has_item);
+	totem_popup_set_sensitivity ("trcm_next_chapter", has_item);
 }
 
 static void
@@ -2878,9 +2924,6 @@ totem_callback_connect (Totem *totem)
 			"tmw_aspect_ratio_dvb_menu_item");
 	g_signal_connect (G_OBJECT (item), "activate",
 			G_CALLBACK (on_aspect_ratio_dvb_activate), totem);
-	item = glade_xml_get_widget (totem->xml, "tmw_show_playlist_menu_item");
-	g_signal_connect (G_OBJECT (item), "activate",
-			G_CALLBACK (on_show_playlist1_activate), totem);
 	item = glade_xml_get_widget (totem->xml, "tmw_repeat_mode_menu_item");
 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item),
 			totem_playlist_get_repeat (totem->playlist));
@@ -2970,19 +3013,10 @@ totem_callback_connect (Totem *totem)
 			G_CALLBACK (on_previous_button_clicked), totem);
 	item = glade_xml_get_widget (totem->xml, "tmw_next_button");
 	g_signal_connect (G_OBJECT (item), "clicked", 
-			G_CALLBACK (on_next_button_clicked), totem);
-	item = glade_xml_get_widget (totem->xml, "tmw_playlist_button");
-	g_signal_connect (G_OBJECT (item), "clicked",
-			G_CALLBACK (on_playlist_button_toggled), totem);
-	item = glade_xml_get_widget (totem->xml, "tmw_volume_mute_button");
-	g_signal_connect (G_OBJECT (item), "clicked",
-			G_CALLBACK (on_volume_mute_button), totem);
-	item = glade_xml_get_widget (totem->xml, "tmw_volume_max_button");
-	g_signal_connect (G_OBJECT (item), "clicked",
-			G_CALLBACK (on_volume_max_button), totem);
+			  G_CALLBACK (on_next_button_clicked), totem);
 
 	/* Drag'n'Drop */
-	item = glade_xml_get_widget (totem->xml, "tmw_playlist_button");
+	item = glade_xml_get_widget (totem->xml, "tmw_sidebar_button");
 	g_signal_connect (G_OBJECT (item), "drag_data_received",
 			G_CALLBACK (drop_playlist_cb), totem);
 	gtk_drag_dest_set (item, GTK_DEST_DEFAULT_ALL,
@@ -3089,13 +3123,6 @@ totem_callback_connect (Totem *totem)
 	g_signal_connect (G_OBJECT (totem->volume), "value-changed",
 			G_CALLBACK (vol_cb), totem);
 
-	/* Playlist Disappearance, woop woop */
-	g_signal_connect (G_OBJECT (totem->playlist), "response",
-			G_CALLBACK (toggle_playlist_from_playlist), totem);
-	g_signal_connect (G_OBJECT (totem->playlist), "delete-event",
-			G_CALLBACK (toggle_playlist_from_playlist),
-			totem);
-
 	/* Playlist */
 	g_signal_connect (G_OBJECT (totem->playlist),
 			"changed", G_CALLBACK (playlist_changed_cb),
@@ -3159,6 +3186,20 @@ totem_callback_connect (Totem *totem)
 	g_timeout_add (600, (GSourceFunc) gui_update_cb, totem);
 }
 
+static void
+playlist_widget_setup (Totem *totem)
+{
+	totem->playlist = TOTEM_PLAYLIST (totem_playlist_new ());
+
+	if (totem->playlist == NULL)
+		totem_action_exit (totem);
+
+	gtk_widget_show_all (GTK_WIDGET (totem->playlist));
+
+	g_signal_connect(totem->playlist, "active-name-changed",
+			G_CALLBACK (on_playlist_change_name), totem);
+}
+
 static void
 video_widget_create (Totem *totem) 
 {
@@ -3187,9 +3228,7 @@ video_widget_create (Totem *totem)
 
 	totem_preferences_tvout_setup (totem);
 	totem_preferences_visuals_setup (totem);
-
-	/* Let's set a name. Will make debugging easier */
-	gtk_widget_set_name (GTK_WIDGET(totem->bvw), "bvw");
+	totem_action_zoom (totem, ZOOM_RESET);
 
 	g_signal_connect (G_OBJECT (totem->bvw),
 			"motion-notify-event",
@@ -3271,28 +3310,6 @@ video_widget_create (Totem *totem)
 	update_volume_sliders (totem);
 }
 
-GtkWidget *
-totem_statusbar_create (void)
-{
-	GtkWidget *widget;
-
-	widget = totem_statusbar_new ();
-	gtk_widget_show (widget);
-
-	return widget;
-}
-
-GtkWidget *
-totem_time_display_create (void)
-{
-	GtkWidget *widget;
-
-	widget = totem_time_label_new ();
-	gtk_widget_show (widget);
-
-	return widget;
-}
-
 static void
 totem_message_connection_receive_cb (const char *msg, Totem *totem)
 {
@@ -3316,6 +3333,18 @@ totem_message_connection_receive_cb (const char *msg, Totem *totem)
 	g_free (url);
 }
 
+GtkWidget *
+totem_volume_create (void)
+{
+	GtkWidget *widget;
+
+	widget = bacon_volume_button_new (GTK_ICON_SIZE_SMALL_TOOLBAR,
+					  0, 100, 1);
+	gtk_widget_show (widget);
+
+	return widget;
+}
+
 int
 main (int argc, char **argv)
 {
@@ -3398,19 +3427,16 @@ main (int argc, char **argv)
 
 	totem_named_icons_init (totem, FALSE);
 
-	/* The playlist */
-	totem->playlist = TOTEM_PLAYLIST (totem_playlist_new ());
-
-	if (totem->playlist == NULL)
-		totem_action_exit (totem);
+	/* The sidebar */
+	playlist_widget_setup (totem);
+	totem_sidebar_setup (totem);
 
 	/* The rest of the widgets */
 	totem->state = STATE_STOPPED;
 	totem->seek = glade_xml_get_widget (totem->xml, "tmw_seek_hscale");
 	totem->seekadj = gtk_range_get_adjustment (GTK_RANGE (totem->seek));
 	g_object_set_data (G_OBJECT (totem->seek), "fs", GINT_TO_POINTER (0));
-	totem->volume = glade_xml_get_widget (totem->xml, "tmw_volume_hscale");
-	totem->voladj = gtk_range_get_adjustment (GTK_RANGE (totem->volume));
+	totem->volume = glade_xml_get_widget (totem->xml, "tcw_volume_button");
 	g_object_set_data (G_OBJECT (totem->volume), "fs", GINT_TO_POINTER (0));
 	totem->exit_popup = glade_xml_get_widget
 		(totem->xml, "totem_exit_fullscreen_window");
@@ -3463,7 +3489,7 @@ main (int argc, char **argv)
 	{
 		totem_session_restore (totem, argv);
 	} else if (argc >= 1 && totem_action_open_files (totem, argv)) {
-			totem_action_play_pause (totem);
+		totem_action_play_pause (totem);
 	} else {
 		totem_action_set_mrl (totem, NULL);
 	}
